@@ -208,12 +208,14 @@ class InvoiceSummaryGenerator(InvoiceSummary):
                       non_zero_calls='1',
                       scc_below_sec=scc_below_sec,
                       ingress_client_id=self.client_id,
+                      ignore_users_limit=True
                       )
         res_all = api.run(start_time=self.start_time, end_time=self.end_time,
                           field='not_zero_calls',
                           group='ingress_client_id',
                           non_zero_calls='1',
-                          ingress_client_id=self.client_id
+                          ingress_client_id=self.client_id,
+                          ignore_users_limit=True
                           )
         if res:
             result = res[0]
@@ -687,6 +689,7 @@ class InvoiceSummaryGenerator(InvoiceSummary):
                           field='not_zero_calls,ingress_bill_time,ingress_call_cost',
                           non_zero_calls='1',
                           ingress_id=self.client._trunks_term_ids,
+                          ignore_users_limit=True
                           )
         items = []
         total = dict(calls=0, minutes=0.0, amount=0.0)
@@ -714,6 +717,7 @@ class InvoiceSummaryGenerator(InvoiceSummary):
                               field='not_zero_calls,ingress_bill_time,ingress_call_cost',
                               non_zero_calls='1',
                               ingress_id=self.client._trunks_term_ids,
+                              ignore_users_limit=True
                               )
         in_res = []
         if self.client._trunks_orig_ids:
@@ -721,6 +725,7 @@ class InvoiceSummaryGenerator(InvoiceSummary):
                              field='not_zero_calls,egress_bill_time,egress_call_cost',
                              non_zero_calls='1',
                              egress_id=self.client._trunks_orig_ids,
+                             ignore_users_limit=True
                              )
         usage_items = []
         total = dict(calls=0, minutes=0.0, amount=0.0)
@@ -758,7 +763,8 @@ class InvoiceSummaryGenerator(InvoiceSummary):
                           field='not_zero_calls,ingress_bill_time,ingress_call_cost',
                           non_zero_calls='1',
                           ingress_id=self.client._trunks_term_az_ids,
-                          group='ingress_id'
+                          group='ingress_id',
+                          ignore_users_limit=True
                           )
         items = []
         total = dict(calls=0, minutes=0.0, amount=0.0)
@@ -783,7 +789,8 @@ class InvoiceSummaryGenerator(InvoiceSummary):
                           field='not_zero_calls,ingress_bill_time,ingress_call_cost',
                           non_zero_calls='1',
                           ingress_id=self.client._trunks_term_ids,
-                          step='day'
+                          step='day',
+                          ignore_users_limit=True
                           )
         items = []
         total = dict(calls=0, minutes=0.0, amount=0.0)
@@ -810,7 +817,7 @@ class InvoiceSummaryGenerator(InvoiceSummary):
                           field='not_zero_calls,inter_not_zero_calls,intra_not_zero_calls,ingress_bill_time,ingress_call_cost,ingress_bill_time_intra,ingress_call_cost_intra,ingress_bill_time_inter,ingress_call_cost_inter',
                           group='ingress_id', non_zero_calls='1',
                           ingress_id=self.client._trunks_term_us_ids,
-
+                          ignore_users_limit=True
                           )
         items = []
         total = dict(total_calls=0, total_minutes=0, total_amount=0.0, inter_calls=0, intra_calls=0,
@@ -857,7 +864,8 @@ class InvoiceSummaryGenerator(InvoiceSummary):
                           field='not_zero_calls,inter_not_zero_calls,intra_not_zero_calls,ingress_bill_time,ingress_call_cost,ingress_bill_time_intra,ingress_call_cost_intra,ingress_bill_time_inter,ingress_call_cost_inter',
                           non_zero_calls='1',
                           ingress_id=self.client._trunks_term_us_ids,
-                          step='day'
+                          step='day',
+                          ignore_users_limit=True
                           )
         items = []
         total = dict(total_calls=0, total_minutes=0, total_amount=0.0, inter_calls=0, intra_calls=0,
@@ -903,7 +911,8 @@ class InvoiceSummaryGenerator(InvoiceSummary):
                           field='not_zero_calls,ingress_bill_time,ingress_call_cost',
                           non_zero_calls='1',
                           ingress_id=self.client._trunks_term_ids,
-                          group='ingress_id,ingress_prefix'
+                          group='ingress_id,ingress_prefix',
+                          ignore_users_limit=True
                           )
         items = []
         total = dict(calls=0, minutes=0.0, amount=0.0)
@@ -928,7 +937,8 @@ class InvoiceSummaryGenerator(InvoiceSummary):
                           field='not_zero_calls,ingress_bill_time,ingress_call_cost',
                           non_zero_calls='1',
                           ingress_id=self.client._trunks_term_ids,
-                          group='ingress_country,ingress_code_name'
+                          group='ingress_country,ingress_code_name',
+                          ignore_users_limit=True
                           )
         items = []
         total = dict(calls=0, minutes=0, amount=0.0)
@@ -955,7 +965,8 @@ class InvoiceSummaryGenerator(InvoiceSummary):
                           field='not_zero_calls,ingress_bill_time,ingress_call_cost',
                           non_zero_calls='1',
                           ingress_id=self.client._trunks_term_ids,
-                          group='ingress_country'
+                          group='ingress_country',
+                          ignore_users_limit=True
                           )
         items = []
         total = dict(calls=0, minutes=0, amount=0.0)
@@ -1014,7 +1025,8 @@ class InvoiceSummaryGenerator(InvoiceSummary):
                           field='not_zero_calls,ingress_bill_time,ingress_call_cost',
                           non_zero_calls='1',
                           ingress_client_id=str(self.client_id),
-                          step='day'
+                          step='day',
+                          ignore_users_limit=True
                           )
         items = []
         total = dict(calls=0.0, minutes=0, amount=0.0)
